@@ -449,14 +449,27 @@ def request_cert(ctx, filename, profile, defaults):
         **values, ns=ns, profile=profile)
     tmp_dir = values.pop('tmp_dir', '/tmp')
     bucket = values.pop('bucket')
-    for x in namespaces:
-        save_to_file(
-            ctx, tmp_dir, values['hostname'],
-            certificate, account_key, key)
-        save_to_s3(
-            ctx, bucket, x, values['hostname'], certificate,
-            account_key, key, tmp_dir=tmp_dir, profile=profile,
-            pfx_password=pfx_password)
+    buckets = values.pop('buckets') or []
+    save_to_file(
+        ctx, tmp_dir, values['hostname'],
+        certificate, account_key, key)
+    if bucket:
+        found = False
+        for x in buckets:
+            if x['name'] == bucket:
+                found = True
+                break
+        if not found:
+            buckets.append(dict(name=bucket))
+    for x in buckets:
+        bucket = x['name']
+        role = x.get('assume_role')
+        profile = x.get('profile') or profile
+        for namespace in namespaces:
+            save_to_s3(
+                ctx, bucket, namespace, values['hostname'], certificate,
+                account_key, key, tmp_dir=tmp_dir, profile=profile,
+                pfx_password=pfx_password, role=role)
 
 
 @task
@@ -514,8 +527,19 @@ def save_to_file(ctx, tmp_dir, hostname, certificate, account_key, key):
         save_to_temp(tmp_dir, filename, content)
 
 
+def assume_role(session, role):
+    sts = session.client('sts')
+    r = sts.assume_role(RoleArn=role)
+    creds = r['Credentials']
+    return Session(
+        aws_access_key_id=creds['AccessKeyId'],
+        aws_secret_access_key=creds['SecretAccessKey'],
+        aws_session_token=creds['SessionToken']
+    )
+
+
 def save_to_s3(ctx, bucket, ns, hostname, certificate, account_key, key,
-               tmp_dir='/tmp', profile=None, pfx_password=None):
+               tmp_dir='/tmp', profile=None, pfx_password=None, role=None):
     """
     saves the contents of the certificate, key, and account keys
     to a local directory for debugging
@@ -527,6 +551,8 @@ def save_to_s3(ctx, bucket, ns, hostname, certificate, account_key, key,
         ('.pfx', pfx_content),
     ]
     session = Session(profile_name=profile)
+    if role:
+        session = assume_role(session, role)
     s3 = session.client('s3')
     for extension, content in contents:
         filename = f'{hostname}{extension}'
